@@ -19,22 +19,19 @@
 
 #include "transportmanager.h"
 #include "mailtransport_defs.h"
-#include "smtpjob.h"
 #include "transport.h"
 #include "transport_p.h"
 #include "transportjob.h"
 #include "transporttype.h"
 #include "transporttype_p.h"
-#include "widgets/addtransportdialog.h"
-#include "widgets/transportconfigdialog.h"
-#include "widgets/transportconfigwidget.h"
-#include "widgets/smtpconfigwidget.h"
-#include "helper_p.h"
+#include "plugins/transportpluginmanager.h"
+#include "plugins/transportabstractplugin.h"
+#include "widgets/addtransportdialogng.h"
 
 #include <QApplication>
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusConnectionInterface>
-#include <QtDBus/QDBusServiceWatcher>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+#include <QDBusServiceWatcher>
 #include <QPointer>
 #include <QRegExp>
 #include <QStringList>
@@ -94,6 +91,7 @@ public:
     void prepareWallet();
     void validateDefault();
     void migrateToWallet();
+    void updatePluginList();
 
     // Slots
     void slotTransportsChanged();
@@ -273,20 +271,27 @@ bool TransportManager::showTransportCreationDialog(QWidget *parent, ShowConditio
         }
     }
 
-    QPointer<AddTransportDialog> dialog = new AddTransportDialog(parent);
+    QPointer<AddTransportDialogNG> dialog = new AddTransportDialogNG(parent);
     const bool accepted = (dialog->exec() == QDialog::Accepted);
     delete dialog;
     return accepted;
 }
 
-bool TransportManager::configureTransport(Transport *transport, QWidget *parent)
+void TransportManager::initializeTransport(const QString &identifier, Transport *transport)
 {
-    QPointer<TransportConfigDialog> transportConfigDialog
-        = new TransportConfigDialog(transport, parent);
-    transportConfigDialog->setWindowTitle(i18n("Configure account"));
-    bool okClicked = (transportConfigDialog->exec() == QDialog::Accepted);
-    delete transportConfigDialog;
-    return okClicked;
+    TransportAbstractPlugin *plugin = TransportPluginManager::self()->plugin(identifier);
+    if (plugin) {
+        return plugin->initializeTransport(transport, identifier);
+    }
+}
+
+bool TransportManager::configureTransport(const QString &identifier, Transport *transport, QWidget *parent)
+{
+    TransportAbstractPlugin *plugin = TransportPluginManager::self()->plugin(identifier);
+    if (plugin) {
+        return plugin->configureTransport(identifier, transport, parent);
+    }
+    return false;
 }
 
 TransportJob *TransportManager::createTransportJob(int transportId)
@@ -297,9 +302,9 @@ TransportJob *TransportManager::createTransportJob(int transportId)
     }
     t = t->clone(); // Jobs delete their transports.
     t->updatePasswordState();
-    switch (t->type()) {
-    case Transport::EnumType::SMTP:
-        return new SmtpJob(t, this);
+    TransportAbstractPlugin *plugin = TransportPluginManager::self()->plugin(t->identifier());
+    if (plugin) {
+        return plugin->createTransportJob(t, t->identifier());
     }
     Q_ASSERT(false);
     return nullptr;
@@ -380,6 +385,10 @@ void TransportManager::removeTransport(int id)
     if (!t) {
         return;
     }
+    auto plugin = MailTransport::TransportPluginManager::self()->plugin(t->identifier());
+    if (plugin) {
+        plugin->cleanUp(t);
+    }
     emit transportRemoved(t->id(), t->name());
 
     d->transports.removeAll(t);
@@ -465,16 +474,34 @@ void TransportManagerPrivate::fillTypes()
 {
     Q_ASSERT(types.isEmpty());
 
-    // SMTP.
-    {
-        TransportType type;
-        type.d->mType = Transport::EnumType::SMTP;
-        type.d->mName = i18nc("@option SMTP transport", "SMTP");
-        type.d->mDescription = i18n("An SMTP server on the Internet");
-        types << type;
+    updatePluginList();
+    QObject::connect(MailTransport::TransportPluginManager::self(), &TransportPluginManager::updatePluginList, q, &TransportManager::updatePluginList);
+}
+
+void TransportManagerPrivate::updatePluginList()
+{
+    types.clear();
+    for (MailTransport::TransportAbstractPlugin *plugin : MailTransport::TransportPluginManager::self()->pluginsList()) {
+        if (plugin->names().isEmpty()) {
+            qCDebug(MAILTRANSPORT_LOG) << "Plugin " << plugin << " doesn't provide plugin";
+        }
+        for (const MailTransport::TransportAbstractPluginInfo &info : plugin->names()) {
+            TransportType type;
+            type.d->mName = info.name;
+            type.d->mDescription = info.description;
+            type.d->mIdentifier = info.identifier;
+            type.d->mIsAkonadiResource = info.isAkonadi;
+            types << type;
+        }
     }
 }
 
+
+void TransportManager::updatePluginList()
+{
+    d->updatePluginList();
+}
+
 void TransportManager::emitChangesCommitted()
 {
     d->myOwnChange = true; // prevent us from reading our changes again
@@ -556,7 +583,7 @@ void TransportManagerPrivate::prepareWallet()
 
 void TransportManager::loadPasswords()
 {
-    foreach (Transport *t, d->transports) {
+    for (Transport *t : qAsConst(d->transports)) {
         t->readPassword();
     }
 
@@ -576,7 +603,7 @@ void TransportManager::loadPasswordsAsync()
 
     // check if there is anything to do at all
     bool found = false;
-    foreach (Transport *t, d->transports) {
+    for (Transport *t : qAsConst(d->transports)) {
         if (!t->isComplete()) {
             found = true;
             break;
@@ -679,7 +706,7 @@ void TransportManagerPrivate::migrateToWallet()
     }
 
     // perform migration
-    foreach (Transport *t, transports) {
+    for (Transport *t : qAsConst(transports)) {
         if (t->needsWalletMigration()) {
             t->migrateToWallet();
         }
@@ -697,3 +724,5 @@ void TransportManagerPrivate::jobResult(KJob *job)
 }
 
 #include "moc_transportmanager.cpp"
+
+#include <MailTransport/TransportAbstractPlugin>
